@@ -1,7 +1,14 @@
 from typing import Any, Dict, Optional
 
-from django.core.exceptions import ImproperlyConfigured, PermissionDenied
+from django.core.exceptions import (
+    ImproperlyConfigured,
+    PermissionDenied,
+    ValidationError,
+)
+from django.http import HttpResponse
 
+from allauth.account.adapter import get_adapter as get_account_adapter
+from allauth.account.internal.emailkit import valid_email_or_none
 from allauth.account.utils import get_next_redirect_url, get_request_param
 from allauth.core import context
 from allauth.socialaccount import app_settings
@@ -25,31 +32,31 @@ class Provider:
     # access/id-token.
     supports_token_authentication = False
 
-    def __init__(self, request, app=None):
+    def __init__(self, request, app=None) -> None:
         self.request = request
         if self.uses_apps and app is None:
             raise ValueError("missing: app")
         self.app = app
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.name
 
     @classmethod
-    def get_slug(cls):
+    def get_slug(cls) -> str:
         return cls.slug or cls.id
 
-    def get_login_url(self, request, next=None, **kwargs):
+    def get_login_url(self, request, next=None, **kwargs) -> str:
         """
         Builds the URL to redirect to when initiating a login for this
         provider.
         """
         raise NotImplementedError("get_login_url() for " + self.name)
 
-    def redirect_from_request(self, request):
+    def redirect_from_request(self, request) -> HttpResponse:
         kwargs = self.get_redirect_from_request_kwargs(request)
         return self.redirect(request, **kwargs)
 
-    def get_redirect_from_request_kwargs(self, request):
+    def get_redirect_from_request_kwargs(self, request) -> dict:
         kwargs = {}
         next_url = get_next_redirect_url(request)
         if next_url:
@@ -57,7 +64,9 @@ class Provider:
         kwargs["process"] = get_request_param(request, "process", AuthProcess.LOGIN)
         return kwargs
 
-    def redirect(self, request, process, next_url=None, data=None, **kwargs):
+    def redirect(
+        self, request, process, next_url=None, data=None, **kwargs
+    ) -> HttpResponse:
         """
         Initiate a redirect to the provider.
         """
@@ -70,7 +79,7 @@ class Provider:
         """
         raise NotImplementedError()
 
-    def media_js(self, request):
+    def media_js(self, request) -> str:
         """
         Some providers may require extra scripts (e.g. a Facebook connect)
         """
@@ -79,7 +88,7 @@ class Provider:
     def wrap_account(self, social_account):
         return self.account_class(social_account)
 
-    def get_settings(self):
+    def get_settings(self) -> dict:
         return app_settings.PROVIDERS.get(self.id, {})
 
     def sociallogin_from_response(self, request, response):
@@ -124,21 +133,35 @@ class Provider:
         email = self.cleanup_email_addresses(
             common_fields.get("email"),
             email_addresses,
-            email_verified=common_fields.get("email_verified"),
+            email_verified=bool(common_fields.get("email_verified")),
         )
         if email:
             common_fields["email"] = email
+        else:
+            common_fields.pop("email", None)
+        phone = common_fields.get("phone")
+        if phone:
+            try:
+                phone = (
+                    get_account_adapter().phone_form_field(required=True).clean(phone)
+                )
+                common_fields["phone"] = phone
+            except ValidationError:
+                phone = None
+                common_fields.pop("phone")
         sociallogin = SocialLogin(
             provider=self,
             account=socialaccount,
             email_addresses=email_addresses,
+            phone=phone,
+            phone_verified=common_fields.get("phone_verified", False),
         )
         user = sociallogin.user = adapter.new_user(request, sociallogin)
         user.set_unusable_password()
         adapter.populate_user(request, sociallogin, common_fields)
         return sociallogin
 
-    def extract_uid(self, data):
+    def extract_uid(self, data) -> str:
         """
         Extracts the unique user ID from `data`
         """
@@ -146,7 +169,7 @@ class Provider:
             "The provider must implement the `extract_uid()` method"
         )
 
-    def extract_extra_data(self, data):
+    def extract_extra_data(self, data) -> dict:
         """
         Extracts fields from `data` that will be stored in
         `SocialAccount`'s `extra_data` JSONField, such as email address, first
@@ -156,7 +179,7 @@ class Provider:
         """
         return data
 
-    def extract_common_fields(self, data):
+    def extract_common_fields(self, data) -> dict:
         """
         Extracts fields from `data` that will be used to populate the
         `User` model in the `SOCIALACCOUNT_ADAPTER`'s `populate_user()`
@@ -176,8 +199,18 @@ class Provider:
         # Avoid loading models before adapters have been registered.
         from allauth.account.models import EmailAddress
 
+        # Validate & clean the email addresses.
+        email = valid_email_or_none(email)
+        # A bit ugly, but the signature of this function is such that we have to
+        # modify addresses in place.
+        for idx in range(len(addresses))[::-1]:
+            address = addresses[idx]
+            address.email = valid_email_or_none(address.email)
+            if not address.email:
+                addresses.pop(idx)
+
         # Move user.email over to EmailAddress
-        if email and email.lower() not in [a.email.lower() for a in addresses]:
+        if email and email not in [a.email for a in addresses]:
             addresses.insert(
                 0,
                 EmailAddress(email=email, verified=bool(email_verified), primary=True),
