@@ -1,6 +1,5 @@
 from allauth.socialaccount.providers.oauth.urls import default_urlpatterns
-
-from .provider import PocketProvider
+from allauth.socialaccount.providers.pocket.provider import PocketProvider
 
 
 urlpatterns = default_urlpatterns(PocketProvider)
