@@ -1,8 +1,6 @@
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
-from allauth.socialaccount.providers.robinhood.views import (
-    RobinhoodOAuth2Adapter,
-)
+from allauth.socialaccount.providers.robinhood.views import RobinhoodOAuth2Adapter
 
 
 class RobinhoodAccount(ProviderAccount):
