@@ -1,6 +1,5 @@
 from allauth.socialaccount.providers.oauth2.urls import default_urlpatterns
-
-from .provider import YandexProvider
+from allauth.socialaccount.providers.yandex.provider import YandexProvider
 
 
 urlpatterns = default_urlpatterns(YandexProvider)
